@@ -2,6 +2,7 @@ from os.path import dirname
 
 import numpy as np
 import pytest
+
 from pysme.abund import Abund
 from pysme.atmosphere.krzfile import KrzFile
 from pysme.linelist.linelist import LineList
@@ -85,13 +86,19 @@ def abund():
 
 
 def test_basic(libsme, wfirst, wlast, vw_scale):
-    """ Test instantiation of library object and some basic functions """
+    """Test instantiation of library object and some basic functions"""
     print(libsme.SMELibraryVersion())
     libsme.InputWaveRange(wfirst, wlast)
     libsme.SetVWscale(vw_scale)
     libsme.SetH2broad()
 
-    print(libsme.file, libsme.wfirst, libsme.wlast, libsme.vw_scale, libsme.h2broad)
+    print(
+        libsme.file,
+        libsme.wfirst,
+        libsme.wlast,
+        libsme.vw_scale,
+        libsme.h2broad,
+    )
 
     # assert libsme.file
     assert libsme.wfirst == wfirst
@@ -101,7 +108,7 @@ def test_basic(libsme, wfirst, wlast, vw_scale):
 
 
 def test_linelist(libsme, linelist):
-    """ Test linelist behaviour """
+    """Test linelist behaviour"""
     libsme.InputLineList(linelist)
     outlist = libsme.OutputLineList()
 
@@ -120,7 +127,7 @@ def test_linelist(libsme, linelist):
 
 
 def test_atmosphere(libsme, atmo, teff, grav, vturb):
-    """ Test atmosphere behaviour """
+    """Test atmosphere behaviour"""
 
     libsme.InputModel(teff, grav, vturb, atmo)
 
@@ -142,7 +149,7 @@ def test_atmosphere(libsme, atmo, teff, grav, vturb):
 
 
 def test_abund(libsme, abund):
-    """ Test abundance behaviour """
+    """Test abundance behaviour"""
     libsme.InputAbund(abund)
 
     # TODO: What should be the expected behaviour?
@@ -169,7 +176,7 @@ def test_transf(
     accrt,
     accwt,
 ):
-    """ Test radiative transfer """
+    """Test radiative transfer"""
     libsme.SetLibraryPath()
 
     libsme.InputLineList(linelist)
